# Security Policy

## Supported Versions

| Version   | Supported          |
| --------- | ------------------ |
| 0.4.x | :white_check_mark: |
| 0.3.x   | :white_check_mark: |

## Reporting a Vulnerability
We encourage you to find vulnerabilities in kube-hunter.
The process is simple, just report a Bug issue. and we will take a look at this.
If you prefer to disclose privately, you can write to one of the security maintainers at:

| Name        | Email              |
| ----------- | ------------------ |
| Daniel Sagi | daniel.sagi@aquasec.com |
